@@ -38,6 +38,7 @@ from .http.http_response import HttpResponse
 from .request import AcsRequest
 from .http import format_type
 from .auth.Signer import Signer
+from .request import CommonRequest
 
 """
 Acs default client module.
@@ -169,6 +170,10 @@ class AcsClient:
         return self._location_service
 
     def _resolve_endpoint(self, request):
+
+        if isinstance(request, CommonRequest) and request.get_domain():
+            return request.get_domain()
+
         endpoint = None
         if request.get_location_service_code() is not None:
             endpoint = self._location_service.find_product_domain(
@@ -220,6 +225,13 @@ class AcsClient:
         return response
 
     def _implementation_of_do_action(self, request):
+        # add core version
+        core_version = __import__('aliyunsdkcore').__version__
+        request.add_header('x-sdk-core-version', core_version)
+
+        if isinstance(request, CommonRequest):
+            request.trans_to_acs_request()
+
         endpoint = self._resolve_endpoint(request)
         http_response = self._make_http_response(endpoint, request)
         if self._url_test_flag:
@@ -265,7 +277,7 @@ class AcsClient:
         try:
             body_obj = json.loads(body)
             request_id = body_obj.get('RequestId')
-        except ValueError, TypeError:
+        except ValueError or TypeError:
             # in case the response body is not a json string, return the raw
             # data instead
             pass
